==> haskell-free-5.1.2-6-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-free.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: free
version: 5.1.2
id: free-5.1.2-A1Qbl3ZcdsO3T5sIellY1Q
key: free-5.1.2-A1Qbl3ZcdsO3T5sIellY1Q
license: BSD-3-Clause
copyright: Copyright (C) 2008-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/free/
synopsis: Monads for free
description:
    Free monads are useful for many tree-like structures and domain specific languages.
    .
    If @f@ is a '\''Functor'\'' then the free '\''Monad'\'' on @f@ is the type
    of trees whose nodes are labeled with the constructors of @f@. The word
    \"free\" is used in the sense of \"unrestricted\" rather than \"zero-cost\":
    @Free f@ makes no constraining assumptions beyond those given by @f@ and the
    definition of '\''Monad'\''. As used here it is a standard term from the
    mathematical theory of adjoint functors.
    .
    Cofree comonads are dual to free monads. They provide convenient ways to talk
    about branching streams and rose-trees, and can be used to annotate syntax
    trees. The cofree comonad can be seen as a stream parameterized by a '\''Functor'\''
    that controls its branching factor.
    .
    More information on free monads, including examples, can be found in the
    following blog posts:
    <http://comonad.com/reader/2008/monads-for-free/>
    <http://comonad.com/reader/2011/free-monads-for-less/>
category: Control, Monads
abi: 233509144eb465a96059b475adeb48b8
exposed: True
exposed-modules:
    Control.Alternative.Free Control.Alternative.Free.Final
    Control.Applicative.Free Control.Applicative.Free.Fast
    Control.Applicative.Free.Final Control.Applicative.Trans.Free
    Control.Comonad.Cofree Control.Comonad.Cofree.Class
    Control.Comonad.Trans.Cofree Control.Comonad.Trans.Coiter
    Control.Monad.Free Control.Monad.Free.Ap Control.Monad.Free.Church
    Control.Monad.Free.Class Control.Monad.Free.TH
    Control.Monad.Trans.Free Control.Monad.Trans.Free.Ap
    Control.Monad.Trans.Free.Church Control.Monad.Trans.Iter
hidden-modules: Data.Functor.Classes.Compat
import-dirs: /usr/lib/ghc-8.6.5/site-local/free-5.1.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/free-5.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/free-5.1.2
hs-libraries: HSfree-5.1.2-A1Qbl3ZcdsO3T5sIellY1Q
includes:
    free-common.h
depends:
    base-4.12.0.0 comonad-5.0.5-CthxCPGmo5h60L0drN1HHd
    containers-0.6.0.1 distributive-0.6-H2z9MTlb1YgoCr4okC28M
    exceptions-0.10.3-L2x6PdAsyEqAgSjmGnIOPt mtl-2.2.2
    profunctors-5.5-C3RSa0newLDGrqKqFpjE7c
    semigroupoids-5.3.3-KFEReOTUWayAwY1pytSwUo
    template-haskell-2.14.0.0 transformers-0.5.6.2
    transformers-base-0.4.5.2-Kv4g21XBkulAq9rkP7VoYL
haddock-interfaces: /usr/share/doc/haskell-free/html/free.haddock
haddock-html: /usr/share/doc/haskell-free/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-free-5.1.2-7-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-free.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: free
version: 5.1.2
id: free-5.1.2-9K5ZNbMJfrIC6OAtSxxaEc
key: free-5.1.2-9K5ZNbMJfrIC6OAtSxxaEc
license: BSD-3-Clause
copyright: Copyright (C) 2008-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/free/
synopsis: Monads for free
description:
    Free monads are useful for many tree-like structures and domain specific languages.
    .
    If @f@ is a '\''Functor'\'' then the free '\''Monad'\'' on @f@ is the type
    of trees whose nodes are labeled with the constructors of @f@. The word
    \"free\" is used in the sense of \"unrestricted\" rather than \"zero-cost\":
    @Free f@ makes no constraining assumptions beyond those given by @f@ and the
    definition of '\''Monad'\''. As used here it is a standard term from the
    mathematical theory of adjoint functors.
    .
    Cofree comonads are dual to free monads. They provide convenient ways to talk
    about branching streams and rose-trees, and can be used to annotate syntax
    trees. The cofree comonad can be seen as a stream parameterized by a '\''Functor'\''
    that controls its branching factor.
    .
    More information on free monads, including examples, can be found in the
    following blog posts:
    <http://comonad.com/reader/2008/monads-for-free/>
    <http://comonad.com/reader/2011/free-monads-for-less/>
category: Control, Monads
abi: 9aa4c3dbe657024d30a08fab0361d039
exposed: True
exposed-modules:
    Control.Alternative.Free Control.Alternative.Free.Final
    Control.Applicative.Free Control.Applicative.Free.Fast
    Control.Applicative.Free.Final Control.Applicative.Trans.Free
    Control.Comonad.Cofree Control.Comonad.Cofree.Class
    Control.Comonad.Trans.Cofree Control.Comonad.Trans.Coiter
    Control.Monad.Free Control.Monad.Free.Ap Control.Monad.Free.Church
    Control.Monad.Free.Class Control.Monad.Free.TH
    Control.Monad.Trans.Free Control.Monad.Trans.Free.Ap
    Control.Monad.Trans.Free.Church Control.Monad.Trans.Iter
hidden-modules: Data.Functor.Classes.Compat
import-dirs: /usr/lib/ghc-8.6.5/site-local/free-5.1.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/free-5.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/free-5.1.2
hs-libraries: HSfree-5.1.2-9K5ZNbMJfrIC6OAtSxxaEc
includes:
    free-common.h
depends:
    base-4.12.0.0 comonad-5.0.5-4oKFRzjdJyn9LPwjAsvqPG
    containers-0.6.0.1 distributive-0.6.1-BcPUpXmGYOcAFyhEcxFEaN
    exceptions-0.10.3-L2x6PdAsyEqAgSjmGnIOPt mtl-2.2.2
    profunctors-5.5-AsNt6U9QGtDLU0jWBMm4n8
    semigroupoids-5.3.3-5c90p3ZZL5SEVl9HRh2nSh
    template-haskell-2.14.0.0 transformers-0.5.6.2
    transformers-base-0.4.5.2-Kv4g21XBkulAq9rkP7VoYL
haddock-interfaces: /usr/share/doc/haskell-free/html/free.haddock
haddock-html: /usr/share/doc/haskell-free/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
